==> GotoBLAS-1.00.tar.gz: GotoBLAS/level2/trmv/trmv_L.c <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#include <stdio.h>
#include <ctype.h>
#include "common.h"

const static FLOAT dp1 = 1.;

int CNAME(long m, FLOAT *a, long lda, FLOAT *b, long incb, void *buffer){

  long i, is;
  long s; 
  FLOAT *subbuffer = buffer + SUB_BUFFER_OFFSET;
  FLOAT *B;

  B = b;

  if (incb != 1) {
    B = subbuffer;
    COPY_K(m, b, incb, subbuffer, 1);
  }
  
  for (is = m; is > 0; is -= TRSV_P1){

    s = MAX(is - TRSV_P1, 0);
    
#ifndef TRANSA
    if (m - is > 0){
      GEMV_N(m - is, MIN(TRSV_P1, is), 0, dp1, 
	     a +  is + s * lda, lda,
	     B +  s, 1,
	     B + is, 1, buffer);
    }
#endif

    for (i = is - 1; i >= s; i--) {

#ifndef UNIT
      B[i*1] *= a[i +  i * lda];
#endif

      if (i - s> 0){
#ifndef TRANSA
	B[i] += DOT_K(i - s, a + i + s * lda, lda, B + s, 1);
#else
	B[i] += DOT_K(i - s, a + s + i * lda, 1,   B + s, 1);
#endif
      }
    }
    
#ifdef TRANSA
    if (s >0){
      GEMV_T(s, TRSV_P1, 0, dp1, 
	     a +  s * lda, lda,
	     B,     1,
	     B + s, 1, buffer);
    }
#endif
  }

  if (incb != 1) {
    COPY_K(m, subbuffer, 1, b, incb);
  }

  return 0;
}

==> GotoBLAS-1.10.tar.gz: GotoBLAS/level2/trmv/trmv_L.c <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#include <stdio.h>
#include <ctype.h>
#include "common.h"

const static FLOAT dp1 = 1.;

int CNAME(long m, FLOAT *a, long lda, FLOAT *b, long incb, void *buffer){

  long i, is, min_i;
  FLOAT *gemvbuffer = (FLOAT *)buffer;
  FLOAT *B = b;

  if (incb != 1) {
    B = buffer;
    gemvbuffer = (FLOAT *)(((long)buffer + m * sizeof(FLOAT) + 4095) & ~4095);
    COPY_K(m, b, incb, buffer, 1);
  }
  
  for (is = m; is > 0; is -= TRSV_P1){

    min_i = MIN(is, TRSV_P1);
    
#ifndef TRANSA
    if (m - is > 0){
      GEMV_N(m - is, min_i, 0, dp1, 
	     a + is + (is - min_i) * lda, lda,
	     B + is - min_i, 1,
	     B + is, 1, gemvbuffer);
    }
#endif

    for (i = 0; i < min_i; i++) {
      FLOAT *AA = a + (is - i - 1) + (is - i - 1) * lda;
      FLOAT *BB = B + (is - i - 1);

#ifndef TRANSA
      if (i > 0) AXPY_K(i, 0, 0, BB[0], AA + 1, 1, BB + 1, 1, NULL, 0);
#endif

#ifndef UNIT
      BB[0] *= AA[0];
#endif

#ifdef TRANSA
      if (i < min_i - 1) BB[0] += DOT_K(min_i - i - 1, AA - (min_i - i - 1), 1, BB - (min_i - i - 1), 1);
#endif
    }
    
#ifdef TRANSA
    if (is - min_i > 0){
      GEMV_T(is - min_i, min_i, 0, dp1, 
	     a +  (is - min_i) * lda, lda,
	     B,              1,
	     B + is - min_i, 1, gemvbuffer);
    }
#endif
  }

  if (incb != 1) {
    COPY_K(m, buffer, 1, b, incb);
  }

  return 0;
}
